@@ -1,8 +1,6 @@
 package Class::MOP;
-BEGIN {
-  $Class::MOP::AUTHORITY = 'cpan:STEVAN';
-}
-$Class::MOP::VERSION = '2.1210';
+our $VERSION = '2.1604';
+
 use strict;
 use warnings;
 
@@ -10,13 +8,13 @@ use 5.008003;
 
 use MRO::Compat;
 use Class::Load 0.07 ();
-use Scalar::Util  'weaken', 'isweak', 'reftype', 'blessed';
+use Scalar::Util  'weaken', 'isweak', 'blessed';
 use Data::OptList;
-use Try::Tiny;
 
 use Class::MOP::Mixin::AttributeCore;
 use Class::MOP::Mixin::HasAttributes;
 use Class::MOP::Mixin::HasMethods;
+use Class::MOP::Mixin::HasOverloads;
 use Class::MOP::Class;
 use Class::MOP::Attribute;
 use Class::MOP::Method;
@@ -32,7 +30,7 @@ BEGIN {
 
 XSLoader::load(
     'Moose',
-    $Class::MOP::{VERSION} ? ${ $Class::MOP::{VERSION} } : ()
+    $VERSION,
 );
 
 {
@@ -170,7 +168,7 @@ Class::MOP::Mixin::HasMethods->meta->add_attribute(
 );
 
 ## --------------------------------------------------------
-## Class::MOP::Mixin::HasMethods
+## Class::MOP::Mixin::HasAttributes
 
 Class::MOP::Mixin::HasAttributes->meta->add_attribute(
     Class::MOP::Attribute->new('attributes' => (
@@ -201,6 +199,20 @@ Class::MOP::Mixin::HasAttributes->meta->add_attribute(
     ))
 );
 
+## --------------------------------------------------------
+## Class::MOP::Mixin::HasOverloads
+
+Class::MOP::Mixin::HasOverloads->meta->add_attribute(
+    Class::MOP::Attribute->new('_overload_map' => (
+        reader   => {
+            '_overload_map' => \&Class::MOP::Mixin::HasOverloads::_overload_map
+        },
+        clearer => '_clear_overload_map',
+        default => sub { {} },
+        _definition_context(),
+    ))
+);
+
 ## --------------------------------------------------------
 ## Class::MOP::Package
 
@@ -617,6 +629,46 @@ Class::MOP::Method::Constructor->meta->add_attribute(
     ))
 );
 
+## --------------------------------------------------------
+## Class::MOP::Overload
+
+Class::MOP::Overload->meta->add_attribute(
+    Class::MOP::Attribute->new(
+        'operator' => (
+            reader   => { 'operator' => \&Class::MOP::Overload::operator },
+            required => 1,
+            _definition_context(),
+        )
+    )
+);
+
+for my $attr (qw( method_name coderef coderef_package coderef_name method )) {
+    Class::MOP::Overload->meta->add_attribute(
+        Class::MOP::Attribute->new(
+            $attr => (
+                reader    => { $attr => Class::MOP::Overload->can($attr) },
+                predicate => {
+                    'has_'
+                        . $attr => Class::MOP::Overload->can( 'has_' . $attr )
+                },
+                _definition_context(),
+            )
+        )
+    );
+}
+
+Class::MOP::Overload->meta->add_attribute(
+    Class::MOP::Attribute->new(
+        'associated_metaclass' => (
+            reader => {
+                'associated_metaclass' =>
+                    \&Class::MOP::Overload::associated_metaclass
+            },
+            _definition_context(),
+        )
+    )
+);
+
 ## --------------------------------------------------------
 ## Class::MOP::Instance
 
@@ -712,7 +764,8 @@ $_->meta->make_immutable(
     Class::MOP::Method::Wrapped
 
     Class::MOP::Method::Meta
-    Class::MOP::Method::Overload
+
+    Class::MOP::Overload
 /;
 
 $_->meta->make_immutable(
@@ -724,6 +777,7 @@ $_->meta->make_immutable(
     Class::MOP::Mixin::AttributeCore
     Class::MOP::Mixin::HasAttributes
     Class::MOP::Mixin::HasMethods
+    Class::MOP::Mixin::HasOverloads
 /;
 
 1;
@@ -742,7 +796,7 @@ Class::MOP - A Meta Object Protocol for Perl 5
 
 =head1 VERSION
 
-version 2.1210
+version 2.1604
 
 =head1 DESCRIPTION
 
@@ -941,16 +995,14 @@ Note that this module does not export any constants or functions.
 
 Note that these are all called as B<functions, not methods>.
 
-=over 4
-
-=item B<Class::MOP::get_code_info($code)>
+=head3 Class::MOP::get_code_info($code)
 
 This function returns two values, the name of the package the C<$code>
 is from and the name of the C<$code> itself. This is used by several
 elements of the MOP to determine where a given C<$code> reference is
 from.
 
-=item B<Class::MOP::class_of($instance_or_class_name)>
+=head3 Class::MOP::class_of($instance_or_class_name)
 
 This will return the metaclass of the given instance or class name.  If the
 class lacks a metaclass, no metaclass will be initialized, and C<undef> will be
@@ -959,8 +1011,6 @@ returned.
 You should almost certainly be using
 L<C<Moose::Util::find_meta>|Moose::Util/find_meta> instead.
 
-=back
-
 =head2 Metaclass cache functions
 
 C<Class::MOP> holds a cache of metaclasses. The following are functions
@@ -968,55 +1018,51 @@ C<Class::MOP> holds a cache of metaclasses. The following are functions
 recommended that you mess with these. Bad things could happen, but if
 you are brave and willing to risk it: go for it!
 
-=over 4
-
-=item B<Class::MOP::get_all_metaclasses>
+=head3 Class::MOP::get_all_metaclasses
 
 This will return a hash of all the metaclass instances that have
 been cached by L<Class::MOP::Class>, keyed by the package name.
 
-=item B<Class::MOP::get_all_metaclass_instances>
+=head3 Class::MOP::get_all_metaclass_instances
 
 This will return a list of all the metaclass instances that have
 been cached by L<Class::MOP::Class>.
 
-=item B<Class::MOP::get_all_metaclass_names>
+=head3 Class::MOP::get_all_metaclass_names
 
 This will return a list of all the metaclass names that have
 been cached by L<Class::MOP::Class>.
 
-=item B<Class::MOP::get_metaclass_by_name($name)>
+=head3 Class::MOP::get_metaclass_by_name($name)
 
 This will return a cached L<Class::MOP::Class> instance, or nothing
 if no metaclass exists with that C<$name>.
 
-=item B<Class::MOP::store_metaclass_by_name($name, $meta)>
+=head3 Class::MOP::store_metaclass_by_name($name, $meta)
 
 This will store a metaclass in the cache at the supplied C<$key>.
 
-=item B<Class::MOP::weaken_metaclass($name)>
+=head3 Class::MOP::weaken_metaclass($name)
 
 In rare cases (e.g. anonymous metaclasses) it is desirable to
 store a weakened reference in the metaclass cache. This
 function will weaken the reference to the metaclass stored
 in C<$name>.
 
-=item B<Class::MOP::metaclass_is_weak($name)>
+=head3 Class::MOP::metaclass_is_weak($name)
 
 Returns true if the metaclass for C<$name> has been weakened
 (via C<weaken_metaclass>).
 
-=item B<Class::MOP::does_metaclass_exist($name)>
+=head3 Class::MOP::does_metaclass_exist($name)
 
 This will return true of there exists a metaclass stored in the
 C<$name> key, and return false otherwise.
 
-=item B<Class::MOP::remove_metaclass_by_name($name)>
+=head3 Class::MOP::remove_metaclass_by_name($name)
 
 This will remove the metaclass stored in the C<$name> key.
 
-=back
-
 Some utility functions (such as C<Class::MOP::load_class>) that were
 previously defined in C<Class::MOP> regarding loading of classes have been
 extracted to L<Class::Load>. Please see L<Class::Load> for documentation.
