@@ -1,5 +1,6 @@
 package Class::MOP::Method;
-$Class::MOP::Method::VERSION = '2.1213';
+our $VERSION = '2.1604';
+
 use strict;
 use warnings;
 
@@ -10,7 +11,11 @@ use parent 'Class::MOP::Object';
 # NOTE:
 # if poked in the right way,
 # they should act like CODE refs.
-use overload '&{}' => sub { $_[0]->body }, fallback => 1;
+use overload
+    '&{}' => sub { $_[0]->body },
+    'bool' => sub { 1 },
+    '""' => sub { overload::StrVal($_[0]) },
+    fallback => 1;
 
 # construction
 
@@ -154,7 +159,7 @@ Class::MOP::Method - Method Meta Object
 
 =head1 VERSION
 
-version 2.1213
+version 2.1604
 
 =head1 DESCRIPTION
 
