@@ -1,15 +1,13 @@
 package Class::MOP::Mixin::HasMethods;
-$Class::MOP::Mixin::HasMethods::VERSION = '2.1213';
+our $VERSION = '2.1604';
+
 use strict;
 use warnings;
 
 use Class::MOP::Method::Meta;
-use Class::MOP::Method::Overload;
 
 use Scalar::Util 'blessed', 'reftype';
-use Sub::Name    'subname';
-
-use overload ();
+use Sub::Name 'subname';
 
 use parent 'Class::MOP::Mixin';
 
@@ -98,8 +96,8 @@ sub has_method {
     ( defined $method_name && length $method_name )
         || $self->_throw_exception( MustDefineAMethodName => instance => $self );
 
-    my $method = $self->_get_maybe_raw_method($method_name)
-        or return;
+    my $method = $self->_get_maybe_raw_method($method_name);
+    return if not $method;
 
     return defined($self->_method_map->{$method_name} = $method);
 }
@@ -110,8 +108,8 @@ sub get_method {
     ( defined $method_name && length $method_name )
         || $self->_throw_exception( MustDefineAMethodName => instance => $self );
 
-    my $method = $self->_get_maybe_raw_method($method_name)
-        or return;
+    my $method = $self->_get_maybe_raw_method($method_name);
+    return if not $method;
 
     return $method if blessed($method) && $method->isa('Class::MOP::Method');
 
@@ -226,97 +224,6 @@ sub _full_method_map {
     return $self->_method_map;
 }
 
-# overloading
-
-my $overload_operators;
-sub overload_operators {
-    $overload_operators ||= [map { split /\s+/ } values %overload::ops];
-    return @$overload_operators;
-}
-
-sub is_overloaded {
-    my $self = shift;
-    return overload::Overloaded($self->name);
-}
-
-# XXX this could probably stand to be cached, but i figure it should be
-# uncommon enough to not particularly matter
-sub _overload_map {
-    my $self = shift;
-
-    return {} unless $self->is_overloaded;
-
-    my %map;
-    for my $op ($self->overload_operators) {
-        my $body = $self->_get_overloaded_operator_body($op);
-        next unless defined $body;
-        $map{$op} = $body;
-    }
-
-    return \%map;
-}
-
-sub get_overload_list {
-    my $self = shift;
-    return keys %{ $self->_overload_map };
-}
-
-sub get_all_overloaded_operators {
-    my $self = shift;
-    my $map = $self->_overload_map;
-    return map { $self->_wrap_overload($_, $map->{$_}) } keys %$map;
-}
-
-sub has_overloaded_operator {
-    my $self = shift;
-    my ($op) = @_;
-    return defined $self->_get_overloaded_operator_body($op);
-}
-
-sub get_overloaded_operator {
-    my $self = shift;
-    my ($op) = @_;
-    my $body = $self->_get_overloaded_operator_body($op);
-    return unless defined $body;
-    return $self->_wrap_overload($op, $body);
-}
-
-sub add_overloaded_operator {
-    my $self = shift;
-    my ($op, $body) = @_;
-    $self->name->overload::OVERLOAD($op => $body);
-}
-
-sub remove_overloaded_operator {
-    my $self = shift;
-    my ($op) = @_;
-
-    if ( $] < 5.018 ) {
-        # ugh, overload.pm provides no api for this - but the problem that
-        # makes this necessary has been fixed in 5.18
-        $self->get_or_add_package_symbol('%OVERLOAD')->{dummy}++;
-    }
-
-    $self->remove_package_symbol('&(' . $op);
-}
-
-sub _get_overloaded_operator_body {
-    my $self = shift;
-    my ($op) = @_;
-    return overload::Method($self->name, $op);
-}
-
-sub _wrap_overload {
-    my $self = shift;
-    my ($op, $body) = @_;
-    return Class::MOP::Method::Overload->wrap(
-        operator             => $op,
-        package_name         => $self->name,
-        associated_metaclass => $self,
-        body                 => $body,
-    );
-}
-
 1;
 
 # ABSTRACT: Methods for metaclasses which have methods
@@ -333,13 +240,13 @@ Class::MOP::Mixin::HasMethods - Methods for metaclasses which have methods
 
 =head1 VERSION
 
-version 2.1213
+version 2.1604
 
 =head1 DESCRIPTION
 
 This class implements methods for metaclasses which have methods
-(L<Class::MOP::Package> and L<Moose::Meta::Role>). See L<Class::MOP::Package>
-for API details.
+(L<Class::MOP::Class> and L<Moose::Meta::Role>). See L<Class::MOP::Class> for
+API details.
 
 =head1 AUTHORS
 
