@@ -1,15 +1,15 @@
 use strict;
 use warnings;
-package Moose;
-$Moose::VERSION = '2.1213';
-$Moose::AUTHORITY = 'cpan:STEVAN';
+package Moose; # git description: 2.1603-10-g5280cac
+our $VERSION = '2.1604';
+our $AUTHORITY = 'cpan:STEVAN';
 
 use 5.008003;
 
-use Scalar::Util 'blessed';
-use Carp         'carp', 'confess';
+use Scalar::Util ();
+use Carp         'carp';
 use Module::Runtime 'module_notional_filename';
-use Class::Load  'is_class_loaded', 'load_class';
+use Class::Load  'is_class_loaded';
 
 use Moose::Deprecated;
 use Moose::Exporter;
@@ -135,8 +135,8 @@ Moose::Exporter->setup_import_methods(
     ],
     as_is => [
         qw( super inner ),
-        \&Carp::confess,
-        \&Scalar::Util::blessed,
+        'Carp::confess',
+        'Scalar::Util::blessed',
     ],
 );
 
@@ -300,7 +300,7 @@ Moose - A postmodern object system for Perl 5
 
 =head1 VERSION
 
-version 2.1213
+version 2.1604
 
 =head1 SYNOPSIS
 
@@ -395,15 +395,27 @@ or coercion.
 =head1 PROVIDED METHODS
 
 Moose provides a number of methods to all your classes, mostly through the
-inheritance of L<Moose::Object>. There is however, one exception.
+inheritance of L<Moose::Object>. There is however, one exception. By default,
+Moose will install a method named C<meta> in any class which uses
+C<Moose>. This method returns the current class's metaclass.
 
-=over 4
+If you'd like to rename this method, you can do so by passing the
+C<-meta_name> option when using Moose:
 
-=item B<meta>
+    use Moose -meta_name => 'my_meta';
 
-This is a method which provides access to the current class's metaclass.
+However, the L<Moose::Object> class I<also> provides a method named C<meta>
+which does the same thing. If your class inherits from L<Moose::Object> (which
+is the default), then you will still have a C<meta> method. However, if your
+class inherits from a parent which provides a C<meta> method of its own, your
+class will inherit that instead.
 
-=back
+If you'd like for Moose to not install a meta method at all, you can pass
+C<undef> as the C<-meta_name> option:
+
+    use Moose -meta_name => undef;
+
+Again, you will still inherit C<meta> from L<Moose::Object> in this case.
 
 =head1 EXPORTED FUNCTIONS
 
@@ -411,9 +423,7 @@ Moose will export a number of functions into the class's namespace which
 may then be used to set up the class. These functions all work directly
 on the current class.
 
-=over 4
-
-=item B<extends (@superclasses)>
+=head2 extends (@superclasses)
 
 This function will set the superclass(es) for the current class. If the parent
 classes are not yet loaded, then C<extends> tries to load them.
@@ -432,7 +442,7 @@ only L<-version|Class::MOP/Class Loading Options> is recognized:
 An exception will be thrown if the version requirements are not
 satisfied.
 
-=item B<with (@roles)>
+=head2 with (@roles)
 
 This will apply a given set of C<@roles> to the local class.
 
@@ -448,7 +458,7 @@ exception will be thrown.
 If your role takes options or arguments, they can be passed along in the
 hash reference as well.
 
-=item B<has $name|@$names =E<gt> %options>
+=head2 has $name|@$names =E<gt> %options
 
 This will install an attribute of a given C<$name> into the current class. If
 the first parameter is an array reference, it will create an attribute for
@@ -708,7 +718,7 @@ $attr->documentation >>.
 
 =back
 
-=item B<has +$name =E<gt> %options>
+=head2 has +$name =E<gt> %options
 
 This is variation on the normal attribute creator C<has> which allows you to
 clone and extend an attribute from a superclass or from a role. Here is an
@@ -785,57 +795,55 @@ B<are not> overridden, or removed.
 
 =back
 
-=item B<before $name|@names|\@names|qr/.../ =E<gt> sub { ... }>
+=head2 before $name|@names|\@names|qr/.../ =E<gt> sub { ... }
 
-=item B<after $name|@names|\@names|qr/.../ =E<gt> sub { ... }>
+=head2 after $name|@names|\@names|qr/.../ =E<gt> sub { ... }
 
-=item B<around $name|@names|\@names|qr/.../ =E<gt> sub { ... }>
+=head2 around $name|@names|\@names|qr/.../ =E<gt> sub { ... }
 
 These three items are syntactic sugar for the before, after, and around method
 modifier features that L<Class::MOP> provides. More information on these may be
 found in L<Moose::Manual::MethodModifiers> and the
 L<Class::MOP::Class documentation|Class::MOP::Class/"Method Modifiers">.
 
-=item B<override ($name, &sub)>
+=head2 override ($name, &sub)
 
 An C<override> method is a way of explicitly saying "I am overriding this
 method from my superclass". You can call C<super> within this method, and
 it will work as expected. The same thing I<can> be accomplished with a normal
 method call and the C<SUPER::> pseudo-package; it is really your choice.
 
-=item B<super>
+=head2 super
 
 The keyword C<super> is a no-op when called outside of an C<override> method. In
 the context of an C<override> method, it will call the next most appropriate
 superclass method with the same arguments as the original method.
 
-=item B<augment ($name, &sub)>
+=head2 augment ($name, &sub)
 
 An C<augment> method, is a way of explicitly saying "I am augmenting this
 method from my superclass". Once again, the details of how C<inner> and
 C<augment> work is best described in the
 L<Moose::Cookbook::Basics::Document_AugmentAndInner>.
 
-=item B<inner>
+=head2 inner
 
 The keyword C<inner>, much like C<super>, is a no-op outside of the context of
 an C<augment> method. You can think of C<inner> as being the inverse of
 C<super>; the details of how C<inner> and C<augment> work is best described in
 the L<Moose::Cookbook::Basics::Document_AugmentAndInner>.
 
-=item B<blessed>
+=head2 blessed
 
 This is the C<Scalar::Util::blessed> function. It is highly recommended that
 this is used instead of C<ref> anywhere you need to test for an object's class
 name.
 
-=item B<confess>
+=head2 confess
 
 This is the C<Carp::confess> function, and exported here for historical
 reasons.
 
-=back
-
 =head1 METACLASS
 
 When you use Moose, you can specify traits which will be applied to your
@@ -939,10 +947,6 @@ unresolvable conflict.
 
 =head1 CAVEATS
 
-=over 4
-
-=item *
-
 It should be noted that C<super> and C<inner> B<cannot> be used in the same
 method. However, they may be combined within the same class hierarchy; see
 F<t/basics/override_augment_inner_super.t> for an example.
@@ -957,8 +961,6 @@ two features separate (yet interoperable) actually makes them easy to use, since
 their behavior is then easier to predict. Time will tell whether I am right or
 not (UPDATE: so far so good).
 
-=back
-
 =head1 GETTING HELP
 
 We offer both a mailing list and a very active IRC channel.
